EDICTOR PHONO CHARTS

Pulmonic Consonants
IPA pulmonic consonants chart image • audio
Place → | Labial | Coronal | Dorsal | Laryngeal
↓ Manner | Bilabial | Labiodental | Linguolabial | Dental | Alveolar | Palato- alveolar | Retroflex | Alveolo- palatal | Palatal | Velar | Uvular | Pharyngeal / Epiglottal | Glottal
Nasal | m̥ | m |  | ɱ | n̼̊ | n̼ | n̥̪ | n̪ | n̥ | n |  | ɳ̊ | ɳ | ȵ̊ | ȵ | ɲ̊ | ɲ | ŋ̊ | ŋ | ɴ̥ | ɴ |
Stop | p | b | p̪ | b̪ | t̼ | d̼ | t̪ | d̪ | t | d |  | ʈ | ɖ |  | c | ɟ | k | ɡ | q | ɢ | ʡ | ʔ |
Sibilant affricate |  |  | ts | dz | tʃ | dʒ | ʈʂ | ɖʐ | tɕ | dʑ |
Non-sibilant affricate | pɸ | bβ | pf | bv |  |  | tθ | dð | tθ̠ | dð̠ | t̠ɹ̠̊˔ | d̠ɹ̠˔ |  |  |  | cç | ɟʝ | kx | ɡɣ | qχ |  | ʡħ | ʡʕ | ʔh |
Sibilant fricative |  |  | s | z | ʃ | ʒ | ʂ | ʐ | ɕ | ʑ |
Non-sibilant fricative | ɸ | β | f | v | θ̼ | ð̼ | θ | ð | θ̱ | ð̠ | ɹ̠̊˔ | ɹ̠˔ |  |  |  | ç | ʝ | x | ɣ | χ | ʁ | ħ | ʕ | h | ɦ ʔ̞
Approximant | ɸ˕ |  | ʋ |  | θ̞ | ɹ̥ | ɹ |  | ɻ̊ | ɻ |  | j̊ | j | ɰ̊ | ɰ |  |
Flap or tap |  | ⱱ̟ |  | ⱱ |  | ɾ̼ |  | ɾ̥ | ɾ |  | ɽ̊ | ɽ |  |  | ɢ̆ |  | ʡ̮ |
Trill |  | ʙ |  |  | r̼ |  | r̥ | r |  | ɽr̥ | ɽr | ʀ̥ | ʀ | ʜ | ʢ
Lateral affricate |  |  |  | tɬ | dɮ |  | ʈɭ̊˔ |  |  | cʎ̥˔ |  | kʟ̝̊ | ɡʟ̝ |  |
Lateral fricative |  |  | ɬ | ɮ |  | ɭ̊˔ |  |  | ʎ̥˔ | ʎ̝ | ʟ̝̊ | ʟ̝ |
Lateral approximant |  | l̼ |  | l̥ | l |  | ɭ̊ | ɭ |  | ʎ̥ | ʎ |  | ʟ |  | ʟ̠
Lateral flap |  | ɺ̼ |  |  | ɺ |  |  | ɭ̆ |  | ʎ̮ |  | ʟ̆ |

Non-pulmonic consonants
Simple clicks | ʘ | ʘ̬ | ʘ̃ | ǀ | ǀ̬ | ǀ̃ | ǃ | ǃ̬ | ǃ̃
ǂ | ǂ̬ | ǂ̃ | ǁ | ǁ̬ | ǁ̃ | ǃ˞ | ǃ̬˞ | ǃ̃˞
Other clicks | ʘ̃ˀ | ʘˀ | ˀʘ̃ | ʘ͡q | ʘ͡qχ | ʘ͡qʼ | ʘ͡qχʼ | ¡ | ʞ
Implosives | ɓ | ɗ | ᶑ | ʄ | ɠ | ʛ |
ɓ̥ | ɗ̥ | ᶑ̥ | ʄ̊ | ɠ̊ | ʛ̥
Ejectives | pʼ | tʼ | ʈʼ | cʼ | kʼ | qʼ | ʡʼ |
fʼ | θʼ | sʼ | ɬʼ | ʃʼ | ʂʼ | ɕʼ | xʼ | χʼ
tsʼ | tɬʼ | tʃʼ | ʈʂʼ | tɕʼ | cʎ̝̥ʼ | kxʼ | kʟ̝̊ʼ | qχʼ

Co-articulated consonants
Continuants | ʍ | w | ɥ̊ | ɥ | ɫ
Occlusives | k͡p | ɡ͡b | ŋ͡m | ɧ
t͡p | d͡b | n͡m | q͡ʡ

Plain Vowels
| Front | Near-​front | Central | Near-​back | Back
Close |
•i y • ɨ ʅ ʉ ʯ • ɯ ɿ u ʮ •ɪ ʏ •ɪ̈ʊ̈ ʊ •e ø •ɘ ɵ •ɤ o •e̞ø̞ •ə ɵ̞ •ɤ̞o̞ •ɛ œ •ɜ ɞ •ʌ ɔ •æ ɐ •a ɶ •ä ɒ̈ •ɑ ɒ
Near-close
Close-mid
Mid
Open-mid
Near-open
Open
Nasal Vowels
| Front | Near-​front | Central | Near-​back | Back
•ĩỹ •ɨ̃ʉ̃ •ɯ̃ũ •ɪ̃ʏ̃ •ɪ̈̃ʊ̈̃ ʊ̃ •ẽø̃ •ɘ̃ɵ̃ •ɤ̃õ •ẽ̞ø̞̃ •ə̃ɵ̞̃ •ɤ̞̃õ̞ •ɛ̃œ̃ •ɜ̃ɞ̃ •ʌ̃ɔ̃ •æ̃ ɐ̃ •ãɶ̃ •ä̃ɒ̈̃ •ɑ̃ɒ̃

Tone System
| Even | Rising | Falling | Contour | Short
--- | --- | --- | --- | --- | ---
High | 55 | 3545 |  | 435 | 5
Mid-High | 44 | 34 24 | 54 | 214 | 4
Mid | 33 | 13 | 53 43 | 213 | 3
Mid-Low | 22 | 12 | 52 42 | 212 | 2
Low | 11 |  | 51 31 21 |  | 1
Neutral Tone | 0